﻿using System;
using System.Collections.Generic;
using System.Web.Mvc;

namespace CDaysDemo.Customizations
{
    public class ConfigurableModelMetadataProvider : DataAnnotationsModelMetadataProvider
    {
        public override ModelMetadata GetMetadataForProperty(Func<object> modelAccessor, Type containerType, string propertyName)
        {
            ModelMetadata result = base.GetMetadataForProperty(modelAccessor, containerType, propertyName);

            if (this.CheckIsRequired(containerType.Name, propertyName))
            {
                result.IsRequired = true;
            }

            string displayName;
            if (this.TryGetDisplayName(containerType.Name, propertyName, out displayName))
            {
                result.DisplayName = displayName;
            }

            return result;
        }

        private List<string> _requiredProperties = new List<string>() 
        {
            "Person.Email"
        };

        private bool CheckIsRequired(string entityName, string propertyName)
        {
            string key = string.Format("{0}.{1}", entityName, propertyName);

            return _requiredProperties.Contains(key);
        }

        private Dictionary<string, string> _displayNames = new Dictionary<string, string>()
        { 
            { "Person.Name", "Nome" }
        };

        private bool TryGetDisplayName(string entityName, string propertyName, out string displayName)
        {
            displayName = string.Empty;

            string key = string.Format("{0}.{1}", entityName, propertyName);

            if (_displayNames.ContainsKey(key))
            {
                displayName = _displayNames[key];
                return true;
            }

            return false;
        }
    }
}