﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web.Mvc;

namespace CDaysDemo.Customizations
{
    public class SplitStringModelBinder : IModelBinder
    {
        public object BindModel(ControllerContext controllerContext, ModelBindingContext bindingContext)
        {
            IList<string> source =
                bindingContext.Model as IList<string>;

            if (source != null)
            {
                IEnumerable<string> fromRequest = this.GetPostedValues(bindingContext);

                if (fromRequest != null)
                {
                    source.Clear();
                    foreach (var value in fromRequest)
                    {
                        source.Add(value);
                    }
                }
            }

            return source;
        }

        private List<string> GetPostedValues(ModelBindingContext bindingContext)
        {
            var postedValue = bindingContext.ValueProvider.GetValue(
                bindingContext.ModelName);

            if (postedValue == null)
                return null;

            return GetValuesFromString(postedValue.AttemptedValue);
        }

        private List<string> GetValuesFromString(string stringValues)
        {
            return stringValues.Split(";".ToCharArray(), StringSplitOptions.RemoveEmptyEntries)
                .ToList();
        }
    }
}